@@ -1,7 +1,6 @@
 package helpers
 
 import (
-	"bytes"
 	"encoding/json"
 	"fmt"
 	"math/rand"
@@ -16,10 +15,8 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/util/wait"
 	"k8s.io/client-go/kubernetes"
-	"k8s.io/client-go/kubernetes/scheme"
 	"k8s.io/client-go/rest"
 	"k8s.io/client-go/tools/clientcmd"
-	"k8s.io/client-go/tools/remotecommand"
 
 	cl "github.com/openshift/cluster-logging-operator/pkg/apis/logging/v1"
 	logforwarding "github.com/openshift/cluster-logging-operator/pkg/apis/logging/v1alpha1"
@@ -27,6 +24,7 @@ import (
 	"github.com/openshift/cluster-logging-operator/pkg/logger"
 	"github.com/openshift/cluster-logging-operator/pkg/utils"
 	e2eutil "github.com/openshift/cluster-logging-operator/test/e2e"
+	"github.com/openshift/cluster-logging-operator/test/helpers/oc"
 )
 
 const (
@@ -55,11 +53,16 @@ func init() {
 }
 
 type LogStore interface {
+	//ApplicationLogs returns app logs for a given log store
+	ApplicationLogs(timeToWait time.Duration) (string, error)
+
 	HasApplicationLogs(timeToWait time.Duration) (bool, error)
 
 	HasInfraStructureLogs(timeToWait time.Duration) (bool, error)
 
 	HasAuditLogs(timeToWait time.Duration) (bool, error)
+
+	GrepLogs(expr string, timeToWait time.Duration) (string, error)
 }
 
 type E2ETestFramework struct {
@@ -95,6 +98,7 @@ func (tc *E2ETestFramework) DeployLogGenerator() error {
 		Containers: []corev1.Container{container},
 	}
 	deployment := k8shandler.NewDeployment("log-generator", namespace, "log-generator", "test", podSpec)
+	logger.Infof("Deploying %q to namespace: %q...", deployment.Name, deployment.Namespace)
 	deployment, err := tc.KubeClient.Apps().Deployments(namespace).Create(deployment)
 	if err != nil {
 		return err
@@ -137,7 +141,7 @@ func (tc *E2ETestFramework) WaitFor(component LogComponentType) error {
 
 func (tc *E2ETestFramework) waitForElasticsearchPods(retryInterval, timeout time.Duration) error {
 	logger.Debugf("Waiting for %v", "elasticsearch")
-	err := wait.Poll(retryInterval, timeout, func() (done bool, err error) {
+	return wait.Poll(retryInterval, timeout, func() (done bool, err error) {
 		options := metav1.ListOptions{
 			LabelSelector: "component=elasticsearch",
 		}
@@ -165,11 +169,10 @@ func (tc *E2ETestFramework) waitForElasticsearchPods(retryInterval, timeout time
 		}
 		return true, nil
 	})
-	return err
 }
 
 func (tc *E2ETestFramework) waitForDeployment(namespace, name string, retryInterval, timeout time.Duration) error {
-	err := wait.Poll(retryInterval, timeout, func() (done bool, err error) {
+	return wait.Poll(retryInterval, timeout, func() (done bool, err error) {
 		deployment, err := tc.KubeClient.AppsV1().Deployments(namespace).Get(name, metav1.GetOptions{IncludeUninitialized: true})
 		if err != nil {
 			if apierrors.IsNotFound(err) {
@@ -183,10 +186,39 @@ func (tc *E2ETestFramework) waitForDeployment(namespace, name string, retryInter
 		}
 		return false, nil
 	})
-	if err != nil {
-		return err
+}
+
+func (tc *E2ETestFramework) WaitForCleanupCompletion(podlabels []string) {
+	if err := tc.waitForClusterLoggingPodsCompletion(podlabels); err != nil {
+		logger.Errorf("Cleanup completion error %v", err)
 	}
-	return nil
+}
+
+func (tc *E2ETestFramework) waitForClusterLoggingPodsCompletion(podlabels []string) error {
+	labels := strings.Join(podlabels, ",")
+	logger.Infof("waiting for pods to complete with labels: %s", labels)
+	labelSelector := fmt.Sprintf("component in (%s)", labels)
+	options := metav1.ListOptions{
+		LabelSelector: labelSelector,
+	}
+
+	return wait.Poll(defaultRetryInterval, defaultTimeout, func() (bool, error) {
+		pods, err := tc.KubeClient.CoreV1().Pods(OpenshiftLoggingNS).List(options)
+		if err != nil {
+			if apierrors.IsNotFound(err) {
+				logger.Infof("Did not find pods %v", err)
+				return false, nil
+			}
+			logger.Infof("Error listing pods %v", err)
+			return false, err
+		}
+		if len(pods.Items) == 0 {
+			logger.Infof("No pods found for label selection: %s", labels)
+			return true, nil
+		}
+		logger.Debug("pods still running...")
+		return false, nil
+	})
 }
 
 func (tc *E2ETestFramework) SetupClusterLogging(componentTypes ...LogComponentType) error {
@@ -239,27 +271,32 @@ func (tc *E2ETestFramework) CreateLogForwarding(forwarding *logforwarding.LogFor
 
 func (tc *E2ETestFramework) Cleanup() {
 	//allow caller to cleanup if unset (e.g script cleanup())
-	if value, exists := os.LookupEnv("CLEANUP_E2E"); exists && value == "false" {
-		return
-	}
-	RunCleanupScript()
-	logger.Debugf("Running %v e2e cleanup functions", len(tc.CleanupFns))
-	for _, cleanup := range tc.CleanupFns {
-		logger.Debug("Running an e2e cleanup function")
-		if err := cleanup(); err != nil {
-			logger.Debugf("Error during cleanup %v", err)
+	logger.Infof("Running Cleanup....")
+	doCleanup := strings.TrimSpace(os.Getenv("DO_CLEANUP"))
+	if doCleanup == "" || strings.ToLower(doCleanup) == "true" {
+		RunCleanupScript()
+		logger.Debugf("Running %v e2e cleanup functions", len(tc.CleanupFns))
+		for _, cleanup := range tc.CleanupFns {
+			logger.Debug("Running an e2e cleanup function")
+			if err := cleanup(); err != nil {
+				logger.Debugf("Error during cleanup %v", err)
+			}
 		}
 	}
 }
 
 func RunCleanupScript() {
 	if value, found := os.LookupEnv("CLEANUP_CMD"); found {
+		if strings.TrimSpace(value) == "" {
+			logger.Info("No cleanup script provided")
+			return
+		}
 		args := strings.Split(value, " ")
 		cmd := exec.Command(args[0], args[1:]...)
 		cmd.Env = nil
 		result, err := cmd.Output()
 		logger.Infof("RunCleanupScript output: %s", string(result))
-		logger.Infof("err: %v", err)
+		logger.Infof("RunCleanupScript err: %v", err)
 	}
 }
 
@@ -284,39 +321,7 @@ func newKubeClient() (*kubernetes.Clientset, *rest.Config) {
 }
 
 func (tc *E2ETestFramework) PodExec(namespace, name, container string, command []string) (string, error) {
-	req := tc.KubeClient.CoreV1().RESTClient().Post().
-		Namespace(namespace).
-		Resource("pods").
-		Name(name).
-		SubResource("exec").
-		Timeout(defaultTimeout).
-		VersionedParams(&corev1.PodExecOptions{
-			Container: container,
-			Command:   command,
-			Stdout:    true,
-			Stderr:    true,
-		}, scheme.ParameterCodec)
-
-	logger.Debugf("req: %v", req)
-	logger.Debugf("req.url: %v", req.URL().String())
-	exec, err := remotecommand.NewSPDYExecutor(tc.RestConfig, "POST", req.URL())
-	logger.Debugf("SPDY Error: %v", err)
-	if err != nil {
-		return "", err
-	}
-
-	var stdout, stderr bytes.Buffer
-	err = exec.Stream(remotecommand.StreamOptions{
-		Stdout: &stdout,
-		Stderr: &stderr,
-	})
-	logger.Debugf("exec.stream Error: %v", err)
-	logger.Debugf("stdout: %v", stdout.String())
-	logger.Debugf("stderr: %v", stderr.String())
-	if err != nil {
-		return "", err
-	}
-	return stdout.String(), nil
+	return oc.Exec().WithNamespace(namespace).Pod(name).Container(container).WithCmd(command[0], command[1:]...).Run()
 }
 
 func (tc *E2ETestFramework) CreatePipelineSecret(pwd, logStoreName, secretName string, otherData map[string][]byte) (secret *corev1.Secret, err error) {
